==> quarkus-github-app-1.15.0-sources.jar: io/quarkiverse/githubapp/runtime/config/GitHubAppRuntimeConfig$$accessor.java <==
package io.quarkiverse.githubapp.runtime.config;
public final class GitHubAppRuntimeConfig$$accessor {
    private GitHubAppRuntimeConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_appId(Object __instance) {
        return ((GitHubAppRuntimeConfig)__instance).appId;
    }
    @SuppressWarnings("unchecked")
    public static void set_appId(Object __instance, Object appId) {
        ((GitHubAppRuntimeConfig)__instance).appId = (java.util.Optional<String>)appId;
    }
    @SuppressWarnings("unchecked")
    public static Object get_appName(Object __instance) {
        return ((GitHubAppRuntimeConfig)__instance).appName;
    }
    @SuppressWarnings("unchecked")
    public static void set_appName(Object __instance, Object appName) {
        ((GitHubAppRuntimeConfig)__instance).appName = (java.util.Optional<String>)appName;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_readConfigFilesFromSourceRepository(Object __instance) {
        return ((GitHubAppRuntimeConfig)__instance).readConfigFilesFromSourceRepository;
    }
    @SuppressWarnings("unchecked")
    public static void set_readConfigFilesFromSourceRepository(Object __instance, boolean readConfigFilesFromSourceRepository) {
        ((GitHubAppRuntimeConfig)__instance).readConfigFilesFromSourceRepository = readConfigFilesFromSourceRepository;
    }
    @SuppressWarnings("unchecked")
    public static Object get_privateKey(Object __instance) {
        return ((GitHubAppRuntimeConfig)__instance).privateKey;
    }
    @SuppressWarnings("unchecked")
    public static void set_privateKey(Object __instance, Object privateKey) {
        ((GitHubAppRuntimeConfig)__instance).privateKey = (java.util.Optional<java.security.PrivateKey>)privateKey;
    }
    @SuppressWarnings("unchecked")
    public static Object get_webhookSecret(Object __instance) {
        return ((GitHubAppRuntimeConfig)__instance).webhookSecret;
    }
    @SuppressWarnings("unchecked")
    public static void set_webhookSecret(Object __instance, Object webhookSecret) {
        ((GitHubAppRuntimeConfig)__instance).webhookSecret = (java.util.Optional<String>)webhookSecret;
    }
    @SuppressWarnings("unchecked")
    public static Object get_webhookProxyUrl(Object __instance) {
        return ((GitHubAppRuntimeConfig)__instance).webhookProxyUrl;
    }
    @SuppressWarnings("unchecked")
    public static void set_webhookProxyUrl(Object __instance, Object webhookProxyUrl) {
        ((GitHubAppRuntimeConfig)__instance).webhookProxyUrl = (java.util.Optional<String>)webhookProxyUrl;
    }
    @SuppressWarnings("unchecked")
    public static Object get_instanceEndpoint(Object __instance) {
        return ((GitHubAppRuntimeConfig)__instance).instanceEndpoint;
    }
    @SuppressWarnings("unchecked")
    public static void set_instanceEndpoint(Object __instance, Object instanceEndpoint) {
        ((GitHubAppRuntimeConfig)__instance).instanceEndpoint = (String)instanceEndpoint;
    }
    @SuppressWarnings("unchecked")
    public static Object get_debug(Object __instance) {
        return ((GitHubAppRuntimeConfig)__instance).debug;
    }
    @SuppressWarnings("unchecked")
    public static void set_debug(Object __instance, Object debug) {
        ((GitHubAppRuntimeConfig)__instance).debug = (io.quarkiverse.githubapp.runtime.config.GitHubAppRuntimeConfig.Debug)debug;
    }
}

==> quarkus-github-app-2.3.1-sources.jar: io/quarkiverse/githubapp/runtime/config/GitHubAppRuntimeConfig$$accessor.java <==
package io.quarkiverse.githubapp.runtime.config;
@io.quarkus.Generated("Quarkus annotation processor")
public final class GitHubAppRuntimeConfig$$accessor {
    private GitHubAppRuntimeConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_appId(Object __instance) {
        return ((GitHubAppRuntimeConfig)__instance).appId;
    }
    @SuppressWarnings("unchecked")
    public static void set_appId(Object __instance, Object appId) {
        ((GitHubAppRuntimeConfig)__instance).appId = (java.util.Optional<String>)appId;
    }
    @SuppressWarnings("unchecked")
    public static Object get_appName(Object __instance) {
        return ((GitHubAppRuntimeConfig)__instance).appName;
    }
    @SuppressWarnings("unchecked")
    public static void set_appName(Object __instance, Object appName) {
        ((GitHubAppRuntimeConfig)__instance).appName = (java.util.Optional<String>)appName;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_readConfigFilesFromSourceRepository(Object __instance) {
        return ((GitHubAppRuntimeConfig)__instance).readConfigFilesFromSourceRepository;
    }
    @SuppressWarnings("unchecked")
    public static void set_readConfigFilesFromSourceRepository(Object __instance, boolean readConfigFilesFromSourceRepository) {
        ((GitHubAppRuntimeConfig)__instance).readConfigFilesFromSourceRepository = readConfigFilesFromSourceRepository;
    }
    @SuppressWarnings("unchecked")
    public static Object get_privateKey(Object __instance) {
        return ((GitHubAppRuntimeConfig)__instance).privateKey;
    }
    @SuppressWarnings("unchecked")
    public static void set_privateKey(Object __instance, Object privateKey) {
        ((GitHubAppRuntimeConfig)__instance).privateKey = (java.util.Optional<java.security.PrivateKey>)privateKey;
    }
    @SuppressWarnings("unchecked")
    public static Object get_webhookSecret(Object __instance) {
        return ((GitHubAppRuntimeConfig)__instance).webhookSecret;
    }
    @SuppressWarnings("unchecked")
    public static void set_webhookSecret(Object __instance, Object webhookSecret) {
        ((GitHubAppRuntimeConfig)__instance).webhookSecret = (java.util.Optional<String>)webhookSecret;
    }
    @SuppressWarnings("unchecked")
    public static Object get_webhookProxyUrl(Object __instance) {
        return ((GitHubAppRuntimeConfig)__instance).webhookProxyUrl;
    }
    @SuppressWarnings("unchecked")
    public static void set_webhookProxyUrl(Object __instance, Object webhookProxyUrl) {
        ((GitHubAppRuntimeConfig)__instance).webhookProxyUrl = (java.util.Optional<String>)webhookProxyUrl;
    }
    @SuppressWarnings("unchecked")
    public static Object get_instanceEndpoint(Object __instance) {
        return ((GitHubAppRuntimeConfig)__instance).instanceEndpoint;
    }
    @SuppressWarnings("unchecked")
    public static void set_instanceEndpoint(Object __instance, Object instanceEndpoint) {
        ((GitHubAppRuntimeConfig)__instance).instanceEndpoint = (String)instanceEndpoint;
    }
    @SuppressWarnings("unchecked")
    public static Object get_restApiEndpoint(Object __instance) {
        return ((GitHubAppRuntimeConfig)__instance).restApiEndpoint;
    }
    @SuppressWarnings("unchecked")
    public static void set_restApiEndpoint(Object __instance, Object restApiEndpoint) {
        ((GitHubAppRuntimeConfig)__instance).restApiEndpoint = (String)restApiEndpoint;
    }
    @SuppressWarnings("unchecked")
    public static Object get_graphqlApiEndpoint(Object __instance) {
        return ((GitHubAppRuntimeConfig)__instance).graphqlApiEndpoint;
    }
    @SuppressWarnings("unchecked")
    public static void set_graphqlApiEndpoint(Object __instance, Object graphqlApiEndpoint) {
        ((GitHubAppRuntimeConfig)__instance).graphqlApiEndpoint = (String)graphqlApiEndpoint;
    }
    @SuppressWarnings("unchecked")
    public static Object get_debug(Object __instance) {
        return ((GitHubAppRuntimeConfig)__instance).debug;
    }
    @SuppressWarnings("unchecked")
    public static void set_debug(Object __instance, Object debug) {
        ((GitHubAppRuntimeConfig)__instance).debug = (io.quarkiverse.githubapp.runtime.config.GitHubAppRuntimeConfig.Debug)debug;
    }
}
